@@ -7,8 +7,8 @@
 ;; Maintainer: Morgan Willcock <morgan@ice9.digital>
 ;; Package-Requires: ((emacs "28.1"))
 ;; URL: https://git.sr.ht/~mew/dialog-mode
-;; Package-Version: 20260211.2014
-;; Package-Revision: 45f82211ecf2
+;; Package-Version: 20260221.2125
+;; Package-Revision: c8f29d6cd7cd
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -331,9 +331,8 @@ bind special completion commands to the space and \"?\" keys."
 
 (defun dialog--forward-prefix-chars ()
   "Move forwards over characters with prefix syntax."
-  (unless (eobp)
-    (when (= (char-syntax (char-after)) ?')
-      (forward-same-syntax))))
+  (while (eq (car (syntax-after (point))) 6)
+    (forward-char)))
 
 (defun dialog--in-comment-p (&optional ppss)
   "Return a non-nil value when inside a comment.
